==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
var ToolActionCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionCheckboxDescriptionMetadata, _super);
    function ToolActionCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxDescriptionMetadata.a == null) {
            ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
        }
        if (a.g(ToolActionCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionCheckboxDescriptionMetadata.d = function (a) {
        ToolActionCheckboxDescriptionMetadata.b(a);
        a.u("ToolActionCheckbox", function () { return new ToolActionCheckboxDescription(); });
        a.t("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.$t = markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
}(Base));
export { ToolActionCheckboxDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
var ToolActionCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionCheckboxDescriptionMetadata, _super);
    function ToolActionCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxDescriptionMetadata.a == null) {
            ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
        }
        if (a.j(ToolActionCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionCheckboxDescriptionMetadata.d = function (a) {
        ToolActionCheckboxDescriptionMetadata.b(a);
        a.aa("ToolActionCheckbox", function () { return new ToolActionCheckboxDescription(); });
        a.z("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.$t = markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
}(Base));
export { ToolActionCheckboxDescriptionMetadata };
